pub enum HelperState {
Answered(Greeting),
Silent(String),
}Expand description
Whether a helper that is present can be used.
Variants
Answered(Greeting)
It answered the handshake, and this is what it answered.
Silent(String)
It is there and this build could not talk to it, with the reason.