pub fn normalize(tokens: &[Token], literals: LiteralNorm) -> Vec<NormToken<'_>>Expand description
Normalize tokens as one scope.
Neighbour context for the preservation rules is taken from within the slice only, so identical slice content always produces an identical normal form regardless of its surroundings.