pub enum DiagnosticKind {
UnterminatedString,
UnterminatedChar,
UnterminatedBlockComment,
UnexpectedCharacter,
UnmatchedDelimiter,
}Expand description
The kind of a recoverable Fast-frontend problem.
Variants
UnterminatedString
A string literal was not closed before end of file.
UnterminatedChar
A character or byte literal was not closed before end of file.
UnterminatedBlockComment
A block comment was not closed before end of file.
UnexpectedCharacter
A byte that does not begin any valid token.
UnmatchedDelimiter
An opening delimiter needed by a unit boundary had no matching closer.