pub enum UnitKind {
Function,
Method,
Impl,
Record,
Closure,
}Expand description
The kind of a coarse code unit used as a clone-report anchor.
Variants
Function
A free function.
Method
A method (a function inside an impl block or a record body).
Impl
An impl block.
Record
A record body: a class, struct or union definition.
Closure
A closure or lambda with a block body.
Implementations