pub enum DirectPropagation {
ResultAdapter,
OptionAdapter,
}Expand description
A closed propagation form established by a compiler helper.
Variants
ResultAdapter
A Result error is propagated while its success value is unchanged.
OptionAdapter
An Option absence is propagated while its success value is unchanged.
Implementations