pub fn aggregate_evidence(
evidence: impl IntoIterator<Item = Option<TestCodeEvidence>>,
) -> Option<TestCodeEvidence>Expand description
Aggregate member evidence for one group.
Every member must be test code for a group to be test code. Among those
groups, one marker is enough to name the aggregate marker; otherwise all
members are path-derived and it names path.