pub struct GroupingStats {
pub units: usize,
pub edges: usize,
pub components: usize,
pub oversized_components: usize,
pub groups: usize,
pub medoid_ejections: usize,
pub sampled_medoids: usize,
pub sampled_medoid_candidates: usize,
pub linkage_splits: usize,
pub singletons: usize,
}Expand description
Counters describing what grouping saw and did.
Fields
units: usizeUnits considered (the input length).
edges: usizeVerified edges considered.
components: usizeInitial connected components carved by union-find.
oversized_components: usizeComponents too large to refine as one piece, cut into pieces of
GroupingConfig::max_component. Reported because the cut can leave
clones of each other in separate groups.
groups: usizeGroups emitted after medoid and complete-linkage refinement.
medoid_ejections: usizeMembers ejected by the medoid constraint (and regrouped elsewhere).
sampled_medoids: usizeComponents whose medoid candidates were sampled rather than exhaustively scored.
sampled_medoid_candidates: usizeTotal distinct-content medoid candidates scored in sampled components.
linkage_splits: usizeMembers removed by complete-linkage splitting.
singletons: usizeMembers left ungrouped as singletons after refinement.