pub fn group_lineage_id(group: &CloneGroupFingerprint) -> GroupLineageIdExpand description
Start a clone-group history from the fingerprint that first identified it.
The separate domain ensures a lineage identifier cannot be mistaken for a current finding identifier even when both are rendered as hexadecimal.